==> pipewire-docs-1%3A0.3.52-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__names.js <==
var group__spa__names =
[
    [ "names.h", "names_8h.html", null ],
    [ "SPA_NAME_SUPPORT_CPU", "group__spa__names.html#ga419f7550308d9b74cf2423772b049d14", null ],
    [ "SPA_NAME_SUPPORT_DBUS", "group__spa__names.html#ga26e449f9f86ba68d8b30c5b74f5b86da", null ],
    [ "SPA_NAME_SUPPORT_LOG", "group__spa__names.html#ga0847db019357b78b2fda5d40da8f2d39", null ],
    [ "SPA_NAME_SUPPORT_LOOP", "group__spa__names.html#ga16aaa669b52a214c66192b76d8103078", null ],
    [ "SPA_NAME_SUPPORT_SYSTEM", "group__spa__names.html#ga1c5ec5f41159cc0037ac36f61496e7e2", null ],
    [ "SPA_NAME_SUPPORT_NODE_DRIVER", "group__spa__names.html#gac795f2d94a7d784a268421c9ff83f758", null ],
    [ "SPA_NAME_CONTROL_MIXER", "group__spa__names.html#gaf312de859ad3bedf1b0f7cfda5071c53", null ],
    [ "SPA_NAME_AUDIO_MIXER", "group__spa__names.html#gab5340c5423b6d13bd99f7b75502d9f5a", null ],
    [ "SPA_NAME_AUDIO_MIXER_DSP", "group__spa__names.html#gad370b196384051ae0e6e29f920bb236b", null ],
    [ "SPA_NAME_AUDIO_PROCESS_FORMAT", "group__spa__names.html#ga396be5fd0d0d7f77895bae3df9661c5c", null ],
    [ "SPA_NAME_AUDIO_PROCESS_CHANNELMIX", "group__spa__names.html#ga67d15b8a717e7e64ac2c73f92b69f717", null ],
    [ "SPA_NAME_AUDIO_PROCESS_RESAMPLE", "group__spa__names.html#ga5f6401302a795408e7e484215e025280", null ],
    [ "SPA_NAME_AUDIO_PROCESS_DEINTERLEAVE", "group__spa__names.html#gaba2e28d9c7732bbc9992aab6c34d65cb", null ],
    [ "SPA_NAME_AUDIO_PROCESS_INTERLEAVE", "group__spa__names.html#ga0b43d949e15c4f27d3e3f0d04311ef85", null ],
    [ "SPA_NAME_AUDIO_CONVERT", "group__spa__names.html#ga35b295254f73d500d2e10914b50efcf8", null ],
    [ "SPA_NAME_AUDIO_ADAPT", "group__spa__names.html#ga4ca9373715177f903a0014796b1d8821", null ],
    [ "SPA_NAME_AEC", "group__spa__names.html#ga1abe79976239b87710c2e50bf5202a3b", null ],
    [ "SPA_NAME_VIDEO_PROCESS_FORMAT", "group__spa__names.html#ga3b2743930157d57db10d9f9761b2ad5e", null ],
    [ "SPA_NAME_VIDEO_PROCESS_SCALE", "group__spa__names.html#gaf8c5034276b9d90ecb0c2581de0ada62", null ],
    [ "SPA_NAME_VIDEO_CONVERT", "group__spa__names.html#gace7963d3a221a84c17c23f47b3d8bf18", null ],
    [ "SPA_NAME_VIDEO_ADAPT", "group__spa__names.html#ga5c0c53fbcf555025bfb5fad90134934d", null ],
    [ "SPA_NAME_API_ALSA_ENUM_UDEV", "group__spa__names.html#gadc55cb279def2f1fe77ab07e272a19e8", null ],
    [ "SPA_NAME_API_ALSA_PCM_DEVICE", "group__spa__names.html#ga010bfd1f2c50f4927df733f5f13e5690", null ],
    [ "SPA_NAME_API_ALSA_PCM_SOURCE", "group__spa__names.html#ga3f4910b31a7f9c759e72b1c1797951a9", null ],
    [ "SPA_NAME_API_ALSA_PCM_SINK", "group__spa__names.html#gaacd7bbe5d5f7f94eb61779967c439092", null ],
    [ "SPA_NAME_API_ALSA_SEQ_DEVICE", "group__spa__names.html#gaea2a7f9455eba0d3fb89870950c0c94d", null ],
    [ "SPA_NAME_API_ALSA_SEQ_SOURCE", "group__spa__names.html#gaca54697235d377d99ccab4d6d240d82f", null ],
    [ "SPA_NAME_API_ALSA_SEQ_SINK", "group__spa__names.html#ga669c4de92ce52f8cd978eafc863733c7", null ],
    [ "SPA_NAME_API_ALSA_SEQ_BRIDGE", "group__spa__names.html#ga2dfd6b7bede9d0057cc3d926a6f6daea", null ],
    [ "SPA_NAME_API_ALSA_ACP_DEVICE", "group__spa__names.html#gae737af4a5b94705cb00880d4e35175d7", null ],
    [ "SPA_NAME_API_BLUEZ5_ENUM_DBUS", "group__spa__names.html#gaee3c98a88d81eec0d1a68908fed7d7d1", null ],
    [ "SPA_NAME_API_BLUEZ5_DEVICE", "group__spa__names.html#ga6f8c2d1151dab294cd25cb2ff6277441", null ],
    [ "SPA_NAME_API_BLUEZ5_A2DP_SINK", "group__spa__names.html#ga9d31cf5ef1e43bb2f1aca6b3dd07a0fa", null ],
    [ "SPA_NAME_API_BLUEZ5_A2DP_SOURCE", "group__spa__names.html#ga45fd55853ff79716c7d4dfaa4b004449", null ],
    [ "SPA_NAME_API_BLUEZ5_SCO_SINK", "group__spa__names.html#gab7e9eec4ea4e014db3a9e4b907559ff6", null ],
    [ "SPA_NAME_API_BLUEZ5_SCO_SOURCE", "group__spa__names.html#ga8146eeb0bad2c0312e0e8c71c3d8496f", null ],
    [ "SPA_NAME_API_CODEC_BLUEZ5_A2DP", "group__spa__names.html#ga823018c8f1ebc388c853534fb888c6a2", null ],
    [ "SPA_NAME_API_V4L2_ENUM_UDEV", "group__spa__names.html#ga63f28346db2b854192c30e714e64f933", null ],
    [ "SPA_NAME_API_V4L2_DEVICE", "group__spa__names.html#gac4ef8bddd1f53a3a890c5ab7bb32db3f", null ],
    [ "SPA_NAME_API_V4L2_SOURCE", "group__spa__names.html#gac74108a61f4492b8c1cb44d39ec84c32", null ],
    [ "SPA_NAME_API_LIBCAMERA_ENUM_CLIENT", "group__spa__names.html#gae6ea9ea9313e276a4bccca85f5a6718f", null ],
    [ "SPA_NAME_API_LIBCAMERA_ENUM_MANAGER", "group__spa__names.html#ga4634945f76f5e790fedccc5431343d69", null ],
    [ "SPA_NAME_API_LIBCAMERA_DEVICE", "group__spa__names.html#gad7a31f482b20d254ce441d8545086b0c", null ],
    [ "SPA_NAME_API_LIBCAMERA_SOURCE", "group__spa__names.html#ga140a10dbb30ba2bbd75eb1612a79bcf5", null ],
    [ "SPA_NAME_API_JACK_DEVICE", "group__spa__names.html#ga4cb20c60fee8e27040787ed9ec9e9a2e", null ],
    [ "SPA_NAME_API_JACK_SOURCE", "group__spa__names.html#ga11c2cbfdfb9e3c5c6f2567527be11f02", null ],
    [ "SPA_NAME_API_JACK_SINK", "group__spa__names.html#gac2d9defa0b11f106341260bc879a3d91", null ],
    [ "SPA_NAME_API_VULKAN_COMPUTE_SOURCE", "group__spa__names.html#ga191088dbac1ee56122ceb215f16604d5", null ],
    [ "SPA_NAME_API_VULKAN_COMPUTE_FILTER", "group__spa__names.html#ga4dbc7ed7f81507d09348aa39215f0edb", null ]
];

==> pipewire-docs-1%3A0.3.84-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__names.js <==
var group__spa__names =
[
    [ "names.h", "names_8h.html", null ],
    [ "SPA_NAME_SUPPORT_CPU", "group__spa__names.html#ga419f7550308d9b74cf2423772b049d14", null ],
    [ "SPA_NAME_SUPPORT_DBUS", "group__spa__names.html#ga26e449f9f86ba68d8b30c5b74f5b86da", null ],
    [ "SPA_NAME_SUPPORT_LOG", "group__spa__names.html#ga0847db019357b78b2fda5d40da8f2d39", null ],
    [ "SPA_NAME_SUPPORT_LOOP", "group__spa__names.html#ga16aaa669b52a214c66192b76d8103078", null ],
    [ "SPA_NAME_SUPPORT_SYSTEM", "group__spa__names.html#ga1c5ec5f41159cc0037ac36f61496e7e2", null ],
    [ "SPA_NAME_SUPPORT_NODE_DRIVER", "group__spa__names.html#gac795f2d94a7d784a268421c9ff83f758", null ],
    [ "SPA_NAME_CONTROL_MIXER", "group__spa__names.html#gaf312de859ad3bedf1b0f7cfda5071c53", null ],
    [ "SPA_NAME_AUDIO_MIXER", "group__spa__names.html#gab5340c5423b6d13bd99f7b75502d9f5a", null ],
    [ "SPA_NAME_AUDIO_MIXER_DSP", "group__spa__names.html#gad370b196384051ae0e6e29f920bb236b", null ],
    [ "SPA_NAME_AUDIO_PROCESS_FORMAT", "group__spa__names.html#ga396be5fd0d0d7f77895bae3df9661c5c", null ],
    [ "SPA_NAME_AUDIO_PROCESS_CHANNELMIX", "group__spa__names.html#ga67d15b8a717e7e64ac2c73f92b69f717", null ],
    [ "SPA_NAME_AUDIO_PROCESS_RESAMPLE", "group__spa__names.html#ga5f6401302a795408e7e484215e025280", null ],
    [ "SPA_NAME_AUDIO_PROCESS_DEINTERLEAVE", "group__spa__names.html#gaba2e28d9c7732bbc9992aab6c34d65cb", null ],
    [ "SPA_NAME_AUDIO_PROCESS_INTERLEAVE", "group__spa__names.html#ga0b43d949e15c4f27d3e3f0d04311ef85", null ],
    [ "SPA_NAME_AUDIO_CONVERT", "group__spa__names.html#ga35b295254f73d500d2e10914b50efcf8", null ],
    [ "SPA_NAME_AUDIO_ADAPT", "group__spa__names.html#ga4ca9373715177f903a0014796b1d8821", null ],
    [ "SPA_NAME_AEC", "group__spa__names.html#ga1abe79976239b87710c2e50bf5202a3b", null ],
    [ "SPA_NAME_VIDEO_PROCESS_FORMAT", "group__spa__names.html#ga3b2743930157d57db10d9f9761b2ad5e", null ],
    [ "SPA_NAME_VIDEO_PROCESS_SCALE", "group__spa__names.html#gaf8c5034276b9d90ecb0c2581de0ada62", null ],
    [ "SPA_NAME_VIDEO_CONVERT", "group__spa__names.html#gace7963d3a221a84c17c23f47b3d8bf18", null ],
    [ "SPA_NAME_VIDEO_ADAPT", "group__spa__names.html#ga5c0c53fbcf555025bfb5fad90134934d", null ],
    [ "SPA_NAME_API_ALSA_ENUM_UDEV", "group__spa__names.html#gadc55cb279def2f1fe77ab07e272a19e8", null ],
    [ "SPA_NAME_API_ALSA_PCM_DEVICE", "group__spa__names.html#ga010bfd1f2c50f4927df733f5f13e5690", null ],
    [ "SPA_NAME_API_ALSA_PCM_SOURCE", "group__spa__names.html#ga3f4910b31a7f9c759e72b1c1797951a9", null ],
    [ "SPA_NAME_API_ALSA_PCM_SINK", "group__spa__names.html#gaacd7bbe5d5f7f94eb61779967c439092", null ],
    [ "SPA_NAME_API_ALSA_SEQ_DEVICE", "group__spa__names.html#gaea2a7f9455eba0d3fb89870950c0c94d", null ],
    [ "SPA_NAME_API_ALSA_SEQ_SOURCE", "group__spa__names.html#gaca54697235d377d99ccab4d6d240d82f", null ],
    [ "SPA_NAME_API_ALSA_SEQ_SINK", "group__spa__names.html#ga669c4de92ce52f8cd978eafc863733c7", null ],
    [ "SPA_NAME_API_ALSA_SEQ_BRIDGE", "group__spa__names.html#ga2dfd6b7bede9d0057cc3d926a6f6daea", null ],
    [ "SPA_NAME_API_ALSA_ACP_DEVICE", "group__spa__names.html#gae737af4a5b94705cb00880d4e35175d7", null ],
    [ "SPA_NAME_API_ALSA_COMPRESS_OFFLOAD_DEVICE", "group__spa__names.html#gaa129e32c69913bea70931505835d168a", null ],
    [ "SPA_NAME_API_ALSA_COMPRESS_OFFLOAD_SINK", "group__spa__names.html#gadc887e81536271d1538500da0fb6be1f", null ],
    [ "SPA_NAME_API_BLUEZ5_ENUM_DBUS", "group__spa__names.html#gaee3c98a88d81eec0d1a68908fed7d7d1", null ],
    [ "SPA_NAME_API_BLUEZ5_DEVICE", "group__spa__names.html#ga6f8c2d1151dab294cd25cb2ff6277441", null ],
    [ "SPA_NAME_API_BLUEZ5_MEDIA_SINK", "group__spa__names.html#ga8eb39736e87cdb644237a55b5d38cf34", null ],
    [ "SPA_NAME_API_BLUEZ5_MEDIA_SOURCE", "group__spa__names.html#gabbb3efb8d60f252208688a11d1dd412e", null ],
    [ "SPA_NAME_API_BLUEZ5_A2DP_SINK", "group__spa__names.html#ga9d31cf5ef1e43bb2f1aca6b3dd07a0fa", null ],
    [ "SPA_NAME_API_BLUEZ5_A2DP_SOURCE", "group__spa__names.html#ga45fd55853ff79716c7d4dfaa4b004449", null ],
    [ "SPA_NAME_API_BLUEZ5_SCO_SINK", "group__spa__names.html#gab7e9eec4ea4e014db3a9e4b907559ff6", null ],
    [ "SPA_NAME_API_BLUEZ5_SCO_SOURCE", "group__spa__names.html#ga8146eeb0bad2c0312e0e8c71c3d8496f", null ],
    [ "SPA_NAME_API_BLUEZ5_MIDI_ENUM", "group__spa__names.html#ga38307a0857ead4864fd8fd8b306d2779", null ],
    [ "SPA_NAME_API_BLUEZ5_MIDI_NODE", "group__spa__names.html#gacffa316f5521c4c5addf2edec39be6d8", null ],
    [ "SPA_NAME_API_CODEC_BLUEZ5_MEDIA", "group__spa__names.html#ga77956282eec82aad57326a661845fec2", null ],
    [ "SPA_NAME_API_V4L2_ENUM_UDEV", "group__spa__names.html#ga63f28346db2b854192c30e714e64f933", null ],
    [ "SPA_NAME_API_V4L2_DEVICE", "group__spa__names.html#gac4ef8bddd1f53a3a890c5ab7bb32db3f", null ],
    [ "SPA_NAME_API_V4L2_SOURCE", "group__spa__names.html#gac74108a61f4492b8c1cb44d39ec84c32", null ],
    [ "SPA_NAME_API_LIBCAMERA_ENUM_CLIENT", "group__spa__names.html#gae6ea9ea9313e276a4bccca85f5a6718f", null ],
    [ "SPA_NAME_API_LIBCAMERA_ENUM_MANAGER", "group__spa__names.html#ga4634945f76f5e790fedccc5431343d69", null ],
    [ "SPA_NAME_API_LIBCAMERA_DEVICE", "group__spa__names.html#gad7a31f482b20d254ce441d8545086b0c", null ],
    [ "SPA_NAME_API_LIBCAMERA_SOURCE", "group__spa__names.html#ga140a10dbb30ba2bbd75eb1612a79bcf5", null ],
    [ "SPA_NAME_API_JACK_DEVICE", "group__spa__names.html#ga4cb20c60fee8e27040787ed9ec9e9a2e", null ],
    [ "SPA_NAME_API_JACK_SOURCE", "group__spa__names.html#ga11c2cbfdfb9e3c5c6f2567527be11f02", null ],
    [ "SPA_NAME_API_JACK_SINK", "group__spa__names.html#gac2d9defa0b11f106341260bc879a3d91", null ],
    [ "SPA_NAME_API_VULKAN_COMPUTE_SOURCE", "group__spa__names.html#ga191088dbac1ee56122ceb215f16604d5", null ],
    [ "SPA_NAME_API_VULKAN_COMPUTE_FILTER", "group__spa__names.html#ga4dbc7ed7f81507d09348aa39215f0edb", null ]
];
